==> flink-1.12.7-src.tgz: flink-1.12.7/flink-kubernetes/src/main/java/org/apache/flink/kubernetes/configuration/KubernetesResourceManagerDriverConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.kubernetes.configuration;

import org.apache.flink.api.common.time.Time;

/**
 * Configuration specific to {@link org.apache.flink.kubernetes.KubernetesResourceManagerDriver}.
 */
public class KubernetesResourceManagerDriverConfiguration {
    private final String clusterId;
    private final Time podCreationRetryInterval;

    public KubernetesResourceManagerDriverConfiguration(
            String clusterId, Time podCreationRetryInterval) {
        this.clusterId = clusterId;
        this.podCreationRetryInterval = podCreationRetryInterval;
    }

    public String getClusterId() {
        return clusterId;
    }

    public Time getPodCreationRetryInterval() {
        return podCreationRetryInterval;
    }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-kubernetes/src/main/java/org/apache/flink/kubernetes/configuration/KubernetesResourceManagerDriverConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.kubernetes.configuration;

import javax.annotation.Nullable;

/**
 * Configuration specific to {@link org.apache.flink.kubernetes.KubernetesResourceManagerDriver}.
 */
public class KubernetesResourceManagerDriverConfiguration {

    private final String clusterId;

    @Nullable private final String webInterfaceUrl;

    public KubernetesResourceManagerDriverConfiguration(
            String clusterId, @Nullable String webInterfaceUrl) {
        this.clusterId = clusterId;
        this.webInterfaceUrl = webInterfaceUrl;
    }

    public String getClusterId() {
        return clusterId;
    }

    @Nullable
    public String getWebInterfaceUrl() {
        return webInterfaceUrl;
    }
}
